#!/bin/env ruby
# -*- coding: utf-8 -*-

# romankanaを設置するファイル構成に合わせて調整してね！
$:.unshift File.join(File.dirname(__FILE__), '..', 'lib')

require 'test/unit'
require 'romankana'

class RomankanaTest < Test::Unit::TestCase
  @@roma_data = {
    'A'=>['あ','ア'],
    'I'=>['い','イ'],
    'U'=>['う','ウ'],
    'E'=>['え','エ'],
    'O'=>['お','オ'],
    'LA'=>['ら','ラ'],
    'LI'=>['り','リ'],
    'LU'=>['る','ル'],
    'LE'=>['れ','レ'],
    'LO'=>['ろ','ロ'],
    'KA'=>['か','カ'],
    'KI'=>['き','キ'],
    'KU'=>['く','ク'],
    'KE'=>['け','ケ'],
    'KO'=>['こ','コ'],
    'KYA'=>['きゃ','キャ'],
    'KYU'=>['きゅ','キュ'],
    'KYO'=>['きょ','キョ'],
    'SA'=>['さ','サ'],
    'SI'=>['し','シ'],
    'SHI'=>['し','シ'],
    'SU'=>['す','ス'],
    'SE'=>['せ','セ'],
    'SO'=>['そ','ソ'],
    'SYA'=>['しゃ','シャ'],
    'SHA'=>['しゃ','シャ'],
    'SYU'=>['しゅ','シュ'],
    'SHU'=>['しゅ','シュ'],
    'SYO'=>['しょ','ショ'],
    'SHO'=>['しょ','ショ'],
    'TA'=>['た','タ'],
    'TI'=>['ち','チ'],
    'CHI'=>['ち','チ'],
    'TU'=>['つ','ツ'],
    'TSU'=>['つ','ツ'],
    'TE'=>['て','テ'],
    'TO'=>['と','ト'],
    'TYA'=>['ちゃ','チャ'],
    'CHA'=>['ちゃ','チャ'],
    'TYU'=>['ちゅ','チュ'],
    'CHU'=>['ちゅ','チュ'],
    'TYO'=>['ちょ','チョ'],
    'CHO'=>['ちょ','チョ'],
    'NA'=>['な','ナ'],
    'NI'=>['に','ニ'],
    'NU'=>['ぬ','ヌ'],
    'NE'=>['ね','ネ'],
    'NO'=>['の','ノ'],
    'NYA'=>['にゃ','ニャ'],
    'NYU'=>['にゅ','ニュ'],
    'NYO'=>['にょ','ニョ'],
    'HA'=>['は','ハ'],
    'HI'=>['ひ','ヒ'],
    'HU'=>['ふ','フ'],
    'FU'=>['ふ','フ'],
    'HE'=>['へ','ヘ'],
    'HO'=>['ほ','ホ'],
    'HYA'=>['ひゃ','ヒャ'],
    'HYU'=>['ひゅ','ヒュ'],
    'HYO'=>['ひょ','ヒョ'],
    'MA'=>['ま','マ'],
    'MI'=>['み','ミ'],
    'MU'=>['む','ム'],
    'ME'=>['め','メ'],
    'MO'=>['も','モ'],
    'MYA'=>['みゃ','ミャ'],
    'MYU'=>['みゅ','ミュ'],
    'MYO'=>['みょ','ミョ'],
    'YA'=>['や','ヤ'],
    'YU'=>['ゆ','ユ'],
    'YO'=>['よ','ヨ'],
    'RA'=>['ら','ラ'],
    'RI'=>['り','リ'],
    'RU'=>['る','ル'],
    'RE'=>['れ','レ'],
    'RO'=>['ろ','ロ'],
    'RYA'=>['りゃ','リャ'],
    'RYU'=>['りゅ','リュ'],
    'RYO'=>['りょ','リョ'],
    'WA'=>['わ','ワ'],
    'WO'=>['を','ヲ'],
    'NN'=>['ん','ン'],
    'GA'=>['が','ガ'],
    'GI'=>['ぎ','ギ'],
    'GU'=>['ぐ','グ'],
    'GE'=>['げ','ゲ'],
    'GO'=>['ご','ゴ'],
    'GYA'=>['ぎゃ','ギャ'],
    'GYU'=>['ぎゅ','ギュ'],
    'GYO'=>['ぎょ','ギョ'],
    'ZA'=>['ざ','ザ'],
    'ZI'=>['じ','ジ'],
    'JI'=>['じ','ジ'],
    'ZU'=>['ず','ズ'],
    'ZE'=>['ぜ','ゼ'],
    'ZO'=>['ぞ','ゾ'],
    'ZYA'=>['じゃ','ジャ'],
    'JA'=>['じゃ','ジャ'],
    'ZYU'=>['じゅ','ジュ'],
    'JU'=>['じゅ','ジュ'],
    'ZYO'=>['じょ','ジョ'],
    'JO'=>['じょ','ジョ'],
    'DA'=>['だ','ダ'],
    'DI'=>['ぢ','ヂ'],
    'DU'=>['づ','ヅ'],
    'DE'=>['で','デ'],
    'DO'=>['ど','ド'],
    'DYA'=>['ぢゃ','ヂャ'],
    'DYU'=>['ぢゅ','ヂュ'],
    'DYO'=>['ぢょ','ヂョ'],
    'BA'=>['ば','バ'],
    'BI'=>['び','ビ'],
    'BU'=>['ぶ','ブ'],
    'BE'=>['べ','ベ'],
    'BO'=>['ぼ','ボ'],
    'BYA'=>['びゃ','ビャ'],
    'BYU'=>['びゅ','ビュ'],
    'BYO'=>['びょ','ビョ'],
    'PA'=>['ぱ','パ'],
    'PI'=>['ぴ','ピ'],
    'PU'=>['ぷ','プ'],
    'PE'=>['ぺ','ペ'],
    'PO'=>['ぽ','ポ'],
    'PYA'=>['ぴゃ','ピャ'],
    'PYU'=>['ぴゅ','ピュ'],
    'PYO'=>['ぴょ','ピョ'],
    'FA'=>['ふぁ','ファ'],
    'FI'=>['ふぃ','フィ'],
    'FE'=>['ふぇ','フェ'],
    'FO'=>['ふぉ','フォ'],
    'FYA'=>['ふゃ','フャ'],
    'FYU'=>['ふゅ','フュ'],
    'FYO'=>['ふょ','フョ'],
    'a'=>['あ','ア'],
    'i'=>['い','イ'],
    'u'=>['う','ウ'],
    'e'=>['え','エ'],
    'o'=>['お','オ'],
    'ka'=>['か','カ'],
    'ki'=>['き','キ'],
    'ku'=>['く','ク'],
    'ke'=>['け','ケ'],
    'ko'=>['こ','コ'],
    'kya'=>['きゃ','キャ'],
    'kyu'=>['きゅ','キュ'],
    'kyo'=>['きょ','キョ'],
    'sa'=>['さ','サ'],
    'si'=>['し','シ'],
    'shi'=>['し','シ'],
    'su'=>['す','ス'],
    'se'=>['せ','セ'],
    'so'=>['そ','ソ'],
    'sya'=>['しゃ','シャ'],
    'sha'=>['しゃ','シャ'],
    'syu'=>['しゅ','シュ'],
    'shu'=>['しゅ','シュ'],
    'syo'=>['しょ','ショ'],
    'sho'=>['しょ','ショ'],
    'ta'=>['た','タ'],
    'ti'=>['ち','チ'],
    'chi'=>['ち','チ'],
    'tu'=>['つ','ツ'],
    'tsu'=>['つ','ツ'],
    'te'=>['て','テ'],
    'to'=>['と','ト'],
    'tya'=>['ちゃ','チャ'],
    'cha'=>['ちゃ','チャ'],
    'tyu'=>['ちゅ','チュ'],
    'chu'=>['ちゅ','チュ'],
    'tyo'=>['ちょ','チョ'],
    'cho'=>['ちょ','チョ'],
    'na'=>['な','ナ'],
    'ni'=>['に','ニ'],
    'nu'=>['ぬ','ヌ'],
    'ne'=>['ね','ネ'],
    'no'=>['の','ノ'],
    'nya'=>['にゃ','ニャ'],
    'nyu'=>['にゅ','ニュ'],
    'nyo'=>['にょ','ニョ'],
    'ha'=>['は','ハ'],
    'hi'=>['ひ','ヒ'],
    'hu'=>['ふ','フ'],
    'fu'=>['ふ','フ'],
    'he'=>['へ','ヘ'],
    'ho'=>['ほ','ホ'],
    'hya'=>['ひゃ','ヒャ'],
    'hyu'=>['ひゅ','ヒュ'],
    'hyo'=>['ひょ','ヒョ'],
    'ma'=>['ま','マ'],
    'mi'=>['み','ミ'],
    'mu'=>['む','ム'],
    'me'=>['め','メ'],
    'mo'=>['も','モ'],
    'mya'=>['みゃ','ミャ'],
    'myu'=>['みゅ','ミュ'],
    'myo'=>['みょ','ミョ'],
    'ya'=>['や','ヤ'],
    'yu'=>['ゆ','ユ'],
    'yo'=>['よ','ヨ'],
    'ra'=>['ら','ラ'],
    'ri'=>['り','リ'],
    'ru'=>['る','ル'],
    're'=>['れ','レ'],
    'ro'=>['ろ','ロ'],
    'rya'=>['りゃ','リャ'],
    'ryu'=>['りゅ','リュ'],
    'ryo'=>['りょ','リョ'],
    'wa'=>['わ','ワ'],
    'wo'=>['を','ヲ'],
    'nn'=>['ん','ン'],
    'ga'=>['が','ガ'],
    'gi'=>['ぎ','ギ'],
    'gu'=>['ぐ','グ'],
    'ge'=>['げ','ゲ'],
    'go'=>['ご','ゴ'],
    'gya'=>['ぎゃ','ギャ'],
    'gyu'=>['ぎゅ','ギュ'],
    'gyo'=>['ぎょ','ギョ'],
    'za'=>['ざ','ザ'],
    'zi'=>['じ','ジ'],
    'ji'=>['じ','ジ'],
    'zu'=>['ず','ズ'],
    'ze'=>['ぜ','ゼ'],
    'zo'=>['ぞ','ゾ'],
    'zya'=>['じゃ','ジャ'],
    'ja'=>['じゃ','ジャ'],
    'zyu'=>['じゅ','ジュ'],
    'ju'=>['じゅ','ジュ'],
    'zyo'=>['じょ','ジョ'],
    'jo'=>['じょ','ジョ'],
    'da'=>['だ','ダ'],
    'di'=>['ぢ','ヂ'],
    'du'=>['づ','ヅ'],
    'de'=>['で','デ'],
    'do'=>['ど','ド'],
    'dya'=>['ぢゃ','ヂャ'],
    'dyu'=>['ぢゅ','ヂュ'],
    'dyo'=>['ぢょ','ヂョ'],
    'ba'=>['ば','バ'],
    'bi'=>['び','ビ'],
    'bu'=>['ぶ','ブ'],
    'be'=>['べ','ベ'],
    'bo'=>['ぼ','ボ'],
    'bya'=>['びゃ','ビャ'],
    'byu'=>['びゅ','ビュ'],
    'byo'=>['びょ','ビョ'],
    'pa'=>['ぱ','パ'],
    'pi'=>['ぴ','ピ'],
    'pu'=>['ぷ','プ'],
    'pe'=>['ぺ','ペ'],
    'po'=>['ぽ','ポ'],
    'pya'=>['ぴゃ','ピャ'],
    'pyu'=>['ぴゅ','ピュ'],
    'pyo'=>['ぴょ','ピョ'],
    'fa'=>['ふぁ','ファ'],
    'fi'=>['ふぃ','フィ'],
    'fe'=>['ふぇ','フェ'],
    'fo'=>['ふぉ','フォ'],
    'fya'=>['ふゃ','フャ'],
    'fyu'=>['ふゅ','フュ'],
    'fyo'=>['ふょ','フョ'],
    'kouenji'=>['こうえんじ','コウエンジ'],
    'kouennji'=>['こうえんじ','コウエンジ'],
    'nisinippori'=>['にしにっぽり','ニシニッポリ'],
    'nishinippori'=>['にしにっぽり','ニシニッポリ'],
    'himonnya'=>['ひもんや','ヒモンヤ'],
  }
  
  @@hiragana_data = {
    'あ'=>['a','ア'],
    'い'=>['i','イ'],
    'う'=>['u','ウ'],
    'え'=>['e','エ'],
    'お'=>['o','オ'],
    'か'=>['ka','カ'],
    'き'=>['ki','キ'],
    'く'=>['ku','ク'],
    'け'=>['ke','ケ'],
    'こ'=>['ko','コ'],
    'きゃ'=>['kya','キャ'],
    'きゅ'=>['kyu','キュ'],
    'きょ'=>['kyo','キョ'],
    'さ'=>['sa','サ'],
    'し'=>['shi','シ'],
    'す'=>['su','ス'],
    'せ'=>['se','セ'],
    'そ'=>['so','ソ'],
    'しゃ'=>['sha','シャ'],
    'しゅ'=>['shu','シュ'],
    'しょ'=>['sho','ショ'],
    'た'=>['ta','タ'],
    'ち'=>['chi','チ'],
    'つ'=>['tsu','ツ'],
    'て'=>['te','テ'],
    'と'=>['to','ト'],
    'ちゃ'=>['cha','チャ'],
    'ちゅ'=>['chu','チュ'],
    'ちょ'=>['cho','チョ'],
    'な'=>['na','ナ'],
    'に'=>['ni','ニ'],
    'ぬ'=>['nu','ヌ'],
    'ね'=>['ne','ネ'],
    'の'=>['no','ノ'],
    'にゃ'=>['nya','ニャ'],
    'にゅ'=>['nyu','ニュ'],
    'にょ'=>['nyo','ニョ'],
    'は'=>['ha','ハ'],
    'ひ'=>['hi','ヒ'],
    'ふ'=>['fu','フ'],
    'へ'=>['he','ヘ'],
    'ほ'=>['ho','ホ'],
    'ひゃ'=>['hya','ヒャ'],
    'ひゅ'=>['hyu','ヒュ'],
    'ひょ'=>['hyo','ヒョ'],
    'ま'=>['ma','マ'],
    'み'=>['mi','ミ'],
    'む'=>['mu','ム'],
    'め'=>['me','メ'],
    'も'=>['mo','モ'],
    'みゃ'=>['mya','ミャ'],
    'みゅ'=>['myu','ミュ'],
    'みょ'=>['myo','ミョ'],
    'や'=>['ya','ヤ'],
    'ゆ'=>['yu','ユ'],
    'よ'=>['yo','ヨ'],
    'ら'=>['ra','ラ'],
    'り'=>['ri','リ'],
    'る'=>['ru','ル'],
    'れ'=>['re','レ'],
    'ろ'=>['ro','ロ'],
    'りゃ'=>['rya','リャ'],
    'りゅ'=>['ryu','リュ'],
    'りょ'=>['ryo','リョ'],
    'わ'=>['wa','ワ'],
    'を'=>['o','ヲ'],
    'ん'=>['n','ン'],
    'が'=>['ga','ガ'],
    'ぎ'=>['gi','ギ'],
    'ぐ'=>['gu','グ'],
    'げ'=>['ge','ゲ'],
    'ご'=>['go','ゴ'],
    'ぎゃ'=>['gya','ギャ'],
    'ぎゅ'=>['gyu','ギュ'],
    'ぎょ'=>['gyo','ギョ'],
    'ざ'=>['za','ザ'],
    'じ'=>['ji','ジ'],
    'ず'=>['zu','ズ'],
    'ぜ'=>['ze','ゼ'],
    'ぞ'=>['zo','ゾ'],
    'じゃ'=>['ja','ジャ'],
    'じゅ'=>['ju','ジュ'],
    'じょ'=>['jo','ジョ'],
    'だ'=>['da','ダ'],
    'ぢ'=>['ji','ヂ'],
    'づ'=>['zu','ヅ'],
    'で'=>['de','デ'],
    'ど'=>['do','ド'],
    'ぢゃ'=>['ja','ヂャ'],
    'ぢゅ'=>['ju','ヂュ'],
    'ぢょ'=>['jo','ヂョ'],
    'ば'=>['ba','バ'],
    'び'=>['bi','ビ'],
    'ぶ'=>['bu','ブ'],
    'べ'=>['be','ベ'],
    'ぼ'=>['bo','ボ'],
    'びゃ'=>['bya','ビャ'],
    'びゅ'=>['byu','ビュ'],
    'びょ'=>['byo','ビョ'],
    'ぱ'=>['pa','パ'],
    'ぴ'=>['pi','ピ'],
    'ぷ'=>['pu','プ'],
    'ぺ'=>['pe','ペ'],
    'ぽ'=>['po','ポ'],
    'ぴゃ'=>['pya','ピャ'],
    'ぴゅ'=>['pyu','ピュ'],
    'ぴょ'=>['pyo','ピョ'],
    'ふぁ'=>['fa','ファ'],
    'ふぃ'=>['fi','フィ'],
    'ふぇ'=>['fe','フェ'],
    'ふぉ'=>['fo','フォ'],
#    'ふゃ'=>['fya','フャ'],
#    'ふゅ'=>['fyu','フュ'],
#    'ふょ'=>['fyo','フョ'],
    'ゔぁ'=>['va','ヴァ'],
    'ゔぃ'=>['vi','ヴィ'],
    'ゔ'=>['vu','ヴ'],
    'ゔぇ'=>['ve','ヴェ'],
    'ゔぉ'=>['vo','ヴォ'],
    'こうえんじ'=>['kouenji','コウエンジ'],
    'にしにっぽり'=>['nishinippori','ニシニッポリ'],
  }
  
  @@katakana_data = {
    'ア'=>['a','あ'],
    'イ'=>['i','い'],
    'ウ'=>['u','う'],
    'エ'=>['e','え'],
    'オ'=>['o','お'],
    'カ'=>['ka','か'],
    'キ'=>['ki','き'],
    'ク'=>['ku','く'],
    'ケ'=>['ke','け'],
    'コ'=>['ko','こ'],
    'キャ'=>['kya','きゃ'],
    'キュ'=>['kyu','きゅ'],
    'キョ'=>['kyo','きょ'],
    'サ'=>['sa','さ'],
    'シ'=>['shi','し'],
    'ス'=>['su','す'],
    'セ'=>['se','せ'],
    'ソ'=>['so','そ'],
    'シャ'=>['sha','しゃ'],
    'シュ'=>['shu','しゅ'],
    'ショ'=>['sho','しょ'],
    'タ'=>['ta','た'],
    'チ'=>['chi','ち'],
    'ツ'=>['tsu','つ'],
    'テ'=>['te','て'],
    'ト'=>['to','と'],
    'チャ'=>['cha','ちゃ'],
    'チュ'=>['chu','ちゅ'],
    'チョ'=>['cho','ちょ'],
    'ナ'=>['na','な'],
    'ニ'=>['ni','に'],
    'ヌ'=>['nu','ぬ'],
    'ネ'=>['ne','ね'],
    'ノ'=>['no','の'],
    'ニャ'=>['nya','にゃ'],
    'ニュ'=>['nyu','にゅ'],
    'ニョ'=>['nyo','にょ'],
    'ハ'=>['ha','は'],
    'ヒ'=>['hi','ひ'],
    'フ'=>['fu','ふ'],
    'ヘ'=>['he','へ'],
    'ホ'=>['ho','ほ'],
    'ヒャ'=>['hya','ひゃ'],
    'ヒュ'=>['hyu','ひゅ'],
    'ヒョ'=>['hyo','ひょ'],
    'マ'=>['ma','ま'],
    'ミ'=>['mi','み'],
    'ム'=>['mu','む'],
    'メ'=>['me','め'],
    'モ'=>['mo','も'],
    'ミャ'=>['mya','みゃ'],
    'ミュ'=>['myu','みゅ'],
    'ミョ'=>['myo','みょ'],
    'ヤ'=>['ya','や'],
    'ユ'=>['yu','ゆ'],
    'ヨ'=>['yo','よ'],
    'ラ'=>['ra','ら'],
    'リ'=>['ri','り'],
    'ル'=>['ru','る'],
    'レ'=>['re','れ'],
    'ロ'=>['ro','ろ'],
    'リャ'=>['rya','りゃ'],
    'リュ'=>['ryu','りゅ'],
    'リョ'=>['ryo','りょ'],
    'ワ'=>['wa','わ'],
    'ヲ'=>['o','を'],
    'ン'=>['n','ん'],
    'ガ'=>['ga','が'],
    'ギ'=>['gi','ぎ'],
    'グ'=>['gu','ぐ'],
    'ゲ'=>['ge','げ'],
    'ゴ'=>['go','ご'],
    'ギャ'=>['gya','ぎゃ'],
    'ギュ'=>['gyu','ぎゅ'],
    'ギョ'=>['gyo','ぎょ'],
    'ザ'=>['za','ざ'],
    'ジ'=>['ji','じ'],
    'ズ'=>['zu','ず'],
    'ゼ'=>['ze','ぜ'],
    'ゾ'=>['zo','ぞ'],
    'ジャ'=>['ja','じゃ'],
    'ジュ'=>['ju','じゅ'],
    'ジョ'=>['jo','じょ'],
    'ダ'=>['da','だ'],
    'ヂ'=>['ji','ぢ'],
    'ヅ'=>['zu','づ'],
    'デ'=>['de','で'],
    'ド'=>['do','ど'],
    'ヂャ'=>['ja','ぢゃ'],
    'ヂュ'=>['ju','ぢゅ'],
    'ヂョ'=>['jo','ぢょ'],
    'バ'=>['ba','ば'],
    'ビ'=>['bi','び'],
    'ブ'=>['bu','ぶ'],
    'ベ'=>['be','べ'],
    'ボ'=>['bo','ぼ'],
    'ビャ'=>['bya','びゃ'],
    'ビュ'=>['byu','びゅ'],
    'ビョ'=>['byo','びょ'],
    'パ'=>['pa','ぱ'],
    'ピ'=>['pi','ぴ'],
    'プ'=>['pu','ぷ'],
    'ペ'=>['pe','ぺ'],
    'ポ'=>['po','ぽ'],
    'ピャ'=>['pya','ぴゃ'],
    'ピュ'=>['pyu','ぴゅ'],
    'ピョ'=>['pyo','ぴょ'],
    'ファ'=>['fa','ふぁ'],
    'フィ'=>['fi','ふぃ'],
    'フェ'=>['fe','ふぇ'],
    'フォ'=>['fo','ふぉ'],
#    'フャ'=>['fya','ふゃ'],
#    'フュ'=>['fyu','ふゅ'],
#    'フョ'=>['fyo','ふょ'],
    'ヴァ'=>['va','ゔぁ'],
    'ヴィ'=>['vi','ゔぃ'],
    'ヴ'=>['vu','ゔ'],
    'ヴェ'=>['ve','ゔぇ'],
    'ヴォ'=>['vo','ゔぉ'],
    'コウエンジ'=>['kouenji','こうえんじ'],
    'ニシニッポリ'=>['nishinippori','にしにっぽり'],
  }  

  
  def test_roman_to_hiragana1
    puts "\n\n#{@method_name}\n"
    
    puts 'ローマ字→ひらがな(to_hiragana)'
    puts '{'
    @@roma_data.each{|key, value|
      assert_equal(value[0], key.to_hiragana)
      puts "'#{key}'=>'#{key.to_hiragana}',"
    }
    puts'}'
    puts "\n\n"
  end
  
  def test_roman_to_hiragana2
    puts "\n\n#{@method_name}\n"
    
    puts 'ローマ字→ひらがな(to_hiragana)'
    puts '{'
    @@roma_data.each{|key, value|
      assert_equal(value[0], key.roman_to_hiragana)
      puts "'#{key}'=>'#{key.roman_to_hiragana}',"
    }
    puts'}'
    puts "\n\n"
  end
  
  def test_roman_to_katakana1
    puts "\n\n#{@method_name}\n"
    
    puts 'ローマ字→カタカナ(to_katakana)'
    puts '{'
    @@roma_data.each{|key, value|
      assert_equal(value[1], key.to_katakana)
      puts "'#{key}'=>'#{key.to_katakana}',"
    }
    puts'}'
    puts "\n\n"
  end
  
  def test_roman_to_katakana2
    puts "\n\n#{@method_name}\n"
    
    puts 'ローマ字→カタカナ(roman_to_katakana)'
    puts '{'
    @@roma_data.each{|key, value|
      assert_equal(value[1], key.roman_to_katakana)
      puts "'#{key}'=>'#{key.roman_to_katakana}',"
    }
    puts'}'
    puts "\n\n"
  end
  
  def test_hiragana_to_roman1
    puts "\n\n#{@method_name}\n"
    
    puts 'ひらがな→ローマ字(to_roman)'
    puts '{'
    @@hiragana_data.each{|key, value|
      assert_equal(value[0], key.to_roman)
      puts "'#{key}'=>'#{key.to_roman}',"
    }
    puts'}'
    puts "\n\n"
  end

  def test_hiragana_to_roman2
    puts "\n\n#{@method_name}\n"
    
    puts 'ひらがな→ローマ字(hiragana_to_roman)'
    puts '{'
    @@hiragana_data.each{|key, value|
      assert_equal(value[0], key.hiragana_to_roman)
      puts "'#{key}'=>'#{key.hiragana_to_roman}',"
    }
    puts'}'
    puts "\n\n"
  end
  
  def test_katakana_to_roman1
    puts "\n\n#{@method_name}\n"
    
    puts 'カタカナ→ローマ字(to_roman)'
    puts '{'
    @@katakana_data.each{|key, value|
      assert_equal(value[0], key.to_roman)
      puts "'#{key}'=>'#{key.to_roman}',"
    }
    puts'}'
    puts "\n\n"
  end

  def test_katakana_to_roman2
    puts "\n\n#{@method_name}\n"
    
    puts 'カタカナ→ローマ字(katakana_to_roman)'
    puts '{'
    @@katakana_data.each{|key, value|
      assert_equal(value[0], key.katakana_to_roman)
      puts "'#{key}'=>'#{key.katakana_to_roman}',"
    }
    puts'}'
    puts "\n\n"
  end

  def test_hiragana_to_katakana
    puts "\n\n#{@method_name}\n"
    
    puts 'ひらがな→カタカナ(to_katakana)'
    puts '{'
    @@hiragana_data.each{|key, value|
      assert_equal(value[1], key.to_katakana)
      puts "'#{key}'=>'#{key.to_katakana}',"
    }
    puts'}'
    puts "\n\n"
  end

  def test_katakana_to_hiragana
    puts "\n\n#{@method_name}\n"
    
    puts 'カタカナ→ひらがな(to_hiragana)'
    puts '{'
    @@katakana_data.each{|key, value|
      assert_equal(value[1], key.to_hiragana)
      puts "'#{key}'=>'#{key.to_hiragana}',"
    }
    puts'}'
    puts "\n\n"
  end  
  
end
